  local addon, ns = ...
  local cfg = CreateFrame("Frame")
  local _, class = UnitClass("player")

  -----------------------------------
  --       SyianaUI-CONFIG
  -----------------------------------

-- Functions config

   cfg.activation = {
     unitframes         = true,  --false = standart unitframes with class color.
     hidegryphones      = false, --true  = hide gryphones on the actionbars.
     hideoderhallbar    = true,  --true  = hide orderhallbar on the top.
     hidetalkinghead    = true,  --true  = hide the talking head over the actionbar for quests etc.
     customcastbars     = true,  --custom castbars with timer icon etc, scroll down for options.
     rangecolor         = true,  --actionbar range color oor oom etc.
     losecontrol        = true,  --hide the background of the cc frame in the middle.
     saysapped          = true,  --saysapped script.
     noredstuff         = false, --hide the cc text on the actionsbars when you get stuned or kickt etc.
     omnicc             = false, --omnicc script, but better use the addon.
     interrupts         = false, --says youre interrupts.
     tabbinder          = false, --bind tab key to only player in pvp areas and in raids to npcs.
     stats              = true, --show fps & ms, scroll down for options.
     autorelease        = false, --auto resurrection for bgs.
     declineduel        = false, --auto decline duel.
   }

-- Cvars

   --SetCVar("CombatDamage",0)
   --SetCVar("showDispelDebuffs",0)
   --SetCVar("showTargetOfTarget",1)
   --SetCVar("statusText",1)
   SetCVar("chatStyle", "classic", "chatStyle")
   SetCVar("ShowClassColorInNameplate", 1)
   SetCVar("floatingCombatTextCombatState", 0)
   SetCVar("floatingCombatTextCombatDamage", 1)
   --SetCVar("noBuffDebuffFilterOnTarget", 1)

-- Castbars config - needs customcastbar activated

   cfg.playercastingbar = {
     scale            = 1,
     pos1             = 0,
     pos2             = 115,
     timer            = true,
     hide             = false,
   }

   cfg.targetcastingbar = {
     scale            = 1.3,
     pos1             = 0,
     pos2             = 150,
     timer            = true,
     hide             = false,
   }

   cfg.focuscastingbar = {
     hide             = false,
   }

-- Fonts config

   cfg.font = STANDARD_TEXT_FONT

-- Actionbars config

  cfg.textures = {
    normal            = "Interface\\AddOns\\SyianaUI\\textures\\gloss",
    flash             = "Interface\\AddOns\\SyianaUI\\textures\\flash",
    hover             = "Interface\\AddOns\\SyianaUI\\textures\\hover",
    pushed            = "Interface\\AddOns\\SyianaUI\\textures\\pushed",
    checked           = "Interface\\AddOns\\SyianaUI\\textures\\checked",
    equipped          = "Interface\\AddOns\\SyianaUI\\textures\\gloss_grey",
    buttonback        = "Interface\\AddOns\\SyianaUI\\textures\\button_background",
    buttonbackflat    = "Interface\\AddOns\\SyianaUI\\textures\\button_background_flat",
    outer_shadow      = "Interface\\AddOns\\SyianaUI\\textures\\outer_shadow",
  }

  cfg.background = {
    showbg            = true,   --show an background image?
    showshadow        = true,   --show an outer shadow?
    useflatbackground = false,  --true uses plain flat color instead
    backgroundcolor   = { r = 0.2, g = 0.2, b = 0.2, a = 0.3},
    shadowcolor       = { r = 0, g = 0, b = 0, a = 0.8},
    classcolored      = false,
    inset             = 5,
  }

  cfg.color = {
    normal            = { r = 0.37, g = 0.3, b = 0.3, },
    equipped          = { r = 0.1, g = 0.5, b = 0.1, },
    classcolored      = false,
  }

  cfg.hotkeys = {
    show            = true,
    fontsize        = 12,
    pos1             = { a1 = "TOPRIGHT", x = 0, y = 0 },
    pos2             = { a1 = "TOPLEFT", x = 0, y = 0 }, --important! two points are needed to make the hotkeyname be inside of the button
  }

  cfg.macroname = {
    show            = false,
    fontsize        = 12,
    pos1             = { a1 = "BOTTOMLEFT", x = 0, y = 0 },
    pos2             = { a1 = "BOTTOMRIGHT", x = 0, y = 0 }, --important! two points are needed to make the macroname be inside of the button
  }

  cfg.itemcount = {
    show            = true,
    fontsize        = 12,
    pos1             = { a1 = "BOTTOMRIGHT", x = 0, y = 0 },
  }

  cfg.cooldown = {
    spacing         = 0,
  }

  --adjust the oneletter abbrev?
  cfg.adjustOneletterAbbrev = true

  --scale of the consolidated tooltip
  cfg.consolidatedTooltipScale = 1.2

  --combine buff and debuff frame - should buffs and debuffs be displayed in one single frame?
  --if you disable this it is intended that you unlock the buff and debuffs and move them apart!
  cfg.combineBuffsAndDebuffs = false

-- Stats config

  cfg.stats = {
    pos1               = "BOTTOMRIGHT",
    pos2               = 0,
    pos3               = "BOTTOMRIGHT",
    pos4               = 15,
  }

-- Buffframe config

  cfg.buffFrame = {
    pos             = { a1 = "TOPRIGHT", af = "Minimap", a2 = "TOPLEFT", x = -35, y = 0 },
    gap             = 30,   --gap between buff and debuff rows
    userplaced      = true, --want to place the bar somewhere else?
    rowSpacing      = 10,
    colSpacing      = 7,
    buttonsPerRow   = 10,
    button = {
      size              = 32,
    },
    icon = {
      padding           = -2,
    },
    border = {
      texture           = "Interface\\AddOns\\SyianaUI\\textures\\gloss",
      color             = { r = 0.4, g = 0.35, b = 0.35, },
      classcolored      = false,
    },
    background = {
      show              = true,  --show backdrop
      edgeFile          = "Interface\\AddOns\\SyianaUI\\textures\\outer_shadow",
      color             = { r = 0, g = 0, b = 0, a = 0.8},
      classcolored      = false,
      inset             = 6,
      padding           = 4,
    },
    duration = {
      font              = cfg.font,
      size              = 12,
      pos               = { a1 = "BOTTOM", x = 0, y = 0 },
    },
    count = {
      font              = cfg.font,
      size              = 11,
      pos               = { a1 = "TOPRIGHT", x = 0, y = 0 },
    },
  }

-- Debuffframe config

  cfg.debuffFrame = {    pos             = { a1 = "TOPRIGHT", af = "Minimap", a2 = "TOPLEFT", x = -35, y = -85 },
    gap             = 10,   --gap between buff and debuff rows
    userplaced      = true, --want to place the bar somewhere else?
    rowSpacing      = 10,
    colSpacing      = 7,
    buttonsPerRow   = 10,
    button = {
      size              = 34,
    },
    icon = {
      padding           = -2,
    },
    border = {
      texture           = "Interface\\AddOns\\SyianaUI\\textures\\gloss",
      color             = { r = 0.4, g = 0.35, b = 0.35, },
      classcolored      = false,
    },
    background = {
      show              = true, --show backdrop
      edgeFile          = "Interface\\AddOns\\SyianaUI\\textures\\outer_shadow",
      color             = { r = 0, g = 0, b = 0, a = 0.8},
      classcolored      = false,
      inset             = 6,
      padding           = 4,
    },
    duration = {
      font              = cfg.font,
      size              = 11,
      pos               = { a1 = "BOTTOM", x = 0, y = 0 },
    },
    count = {
      font              = cfg.font,
      size              = 11,
      pos               = { a1 = "TOPRIGHT", x = 0, y = 0 },
    },
  }

-- Unitframes config

whoaUnitFrames = {}
whoaUnitFrames.config = {
	classColor = true,				-- true or false
  darkiconsborder = true,   -- dark icons over unitframe
	largeAuraSize = 27,				-- Blizzard default value is 21
	smallAuraSize = 21,				-- Blizzard default value is 17
	customStatusText = true,		-- true or false (If this is false, all following points receive no consideration!)
	autoManaPercent = true,		-- true or false (If this is true, percentages where shown for mana classes!)
	thousandSeparators = true,		-- true or false
	simpleHealth = true,			-- rounds healthpoints over 99.999 (200.000 to 200 k, 3.000.000 to 3 m)
	showMaxHealth = false,			-- true or false - show the maximum healthpoints - Useful to get an idea of PVP opponents gear.
	scale = 1.0,					-- scaling for Focus-, Player- and TargetFrame
	petFrameOnTop = false,			-- true or false - Shows the PetFrame above the PlayerFrame.
	hitIndicators = true,			-- true or false - Do you wanna see the hitindicators on PlayerFrame and PetFrame?
	showToTName = false,			-- true or false - Shows the Name of the ToT beside your TargetFrame.
	--
	customFontSize = 10;			-- It used to work. Sets whoaUF text size for player, target and focus. default: 10
}

whoaUnitFrames.config.phrases = {
	["1000 separator"] = ".",
	["Dead"] = "|cFFFFFFFFDead|r",
	["Ghost"] = "|cFFFFFFFFGhost|r",
	["Offline"] = "|cFFFFFFFFOffline|r",
	["kilo"] = " K",  -- simpleHealth 1.000
	["mega"] = " M",  -- simpleHealth 1.000.000
	["giga"] = " G",  -- simpleHealth 1.000.000.000
}

if class == "PRIEST" then
whoaUnitFrames.config.repositionPartyText = false
	-- whoaUnitFrames.config.largeAuraSize = 27
	-- whoaUnitFrames.config.smallAuraSize = 21
	-- whoaUnitFrames.config.autoManaPercent = true
	-- whoaUnitFrames.config.classColor = false
end
if class == "DRUID" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "MONK" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "MAGE" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "PALADIN" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "SHAMAN" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "WARLOCK" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "DEATHKNIGHT" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "HUNTER" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "ROGUE" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "WARRIOR" then
	whoaUnitFrames.config.repositionPartyText = false
end
if class == "DEMONHUNTER" then
	whoaUnitFrames.config.repositionPartyText = false
end

-- Chat config

  local _, nChat = ...
  nChat.Config = {
      disableFade = false,
      chatOutline = false,

      enableChatWindowBorder = false,

      enableBottomButton     = false,
      enableHyperlinkTooltip = false,
      enableBorderColoring   = true,

      showInputBoxAbove = true,  -- Show the chat input box above the chat window

      tab = {
          fontSize = 14,
          fontOutline = true,
          normalColor = {1, 1, 1},
          specialColor = {0.9, 0.9, 0.9},
          selectedColor = {0.8, 0.8, 0.8},
      },
  }

ns.cfg = cfg
